# FTIR_Deconvolution
Python package to perform deconvolution of spectra. Designed primarily for FTIR deconvolution of silk films. 

## Installation
```bash
pip install ylftir
```

## Usage
```python
import ylftir

# TODO: Add usage example
```
